Skip to contents

Sets the mediocre theme and colors for the whole document.

Usage

set_mediocre_all(
  pal = "autumn",
  gradient = NULL,
  background = FALSE,
  black_text = FALSE,
  second_pair = FALSE,
  base_size = if (.Platform$OS.type == "windows") 17 else 14,
  base_family = "Lato",
  base_line_size = base_size/50,
  base_rect_size = base_size/170
)

Arguments

pal

a string. Defines the color palette selected. Can either be either "autumn", "rainbow", "green", "hotcold", "blackandwhite", "coty", "leo", "portal" or "pem"

gradient

a string, either "left" or "right". Turns divergent palettes into gradient ones by splitting it in two. If equal to "right", the gradient palette is built with the right hand side part of the divergent palette. If equal to "left", uses the left hand side but flipping so that light values are on the left.

background

If TRUE, a background is added to the plots

black_text

If TRUE, the text will be in black, overriding the palette text color

second_pair

if true sets an alternative pair of colors for graphs with two colors

base_size

Base font size, given in pts.

base_family

Base font family

base_line_size

Base size for line elements

base_rect_size

Base size for rect elements

Examples

set_mediocre_all()